@@ -23,11 +23,11 @@
 #include <unistd.h>
 
 #include "lib/dasd_base.h"
-#include "lib/util_base.h"
 #include "lib/util_file.h"
 #include "lib/util_libc.h"
 #include "lib/util_opt.h"
 #include "lib/util_prg.h"
+#include "lib/util_path.h"
 #include "lib/zt_common.h"
 
 #define RD_BUFFER_SIZE 80
@@ -283,18 +283,18 @@ static int dinfo_create_devnode(dev_t dev, char **devno)
 	char filename[] = "dasdinfo0000";
 	mode_t mode;
 	unsigned int path;
-	int retry;
+	unsigned int retry;
 	int rc;
 	int fd;
 
 	mode = S_IFBLK | S_IRWXU;
 
 	/* Try several locations for the temporary device node. */
-	for (path = 0; path < UTIL_ARRAY_SIZE(pathname); path++) {
+	for (path = 0; path < ARRAY_SIZE(pathname); path++) {
 		if (pathname[path] == NULL)
 			continue;
 		for (retry = 0; retry < TEMP_DEV_MAX_RETRIES; retry++) {
-			sprintf(filename, "dasdinfo%04d", retry);
+			snprintf(filename, sizeof(filename), "dasdinfo%04d", retry);
 			result = dinfo_make_path(pathname[path], filename);
 			if (result == NULL)
 				return -1;
@@ -354,18 +354,26 @@ static int dinfo_extract_dev(dev_t *dev, char *str)
 static int dinfo_get_dev_from_blockdev(char *blockdev, dev_t *dev)
 {
 	char *readbuf = NULL;
+	char *path;
 
 	readbuf = dinfo_malloc(RD_BUFFER_SIZE);
 	if (!readbuf) {
 		warnx("Error: Not enough memory to allocate readbuffer");
 		return -1;
 	}
-	if (util_file_read_line(readbuf, RD_BUFFER_SIZE,
-				"/sys/block/%s/dev", blockdev) < 0)
+	path = util_path_sysfs("block/%s/dev", blockdev);
+	if (util_file_read_line(readbuf, RD_BUFFER_SIZE, path) < 0) {
+		free(path);
+		free(readbuf);
 		return -1;
-	if (dinfo_extract_dev(dev, readbuf) != 0)
+	}
+	free(path);
+	if (dinfo_extract_dev(dev, readbuf) != 0) {
+		free(readbuf);
 		return -1;
+	}
 
+	free(readbuf);
 	return 0;
 }
 
@@ -373,8 +381,9 @@ static int
 dinfo_is_busiddir(const char *fpath, const struct stat *UNUSED(sb),
 		  int tflag, struct FTW *ftwbuf)
 {
+	enum { LINK_DIR_SIZE = 128 };
+	char linkdir[LINK_DIR_SIZE];
 	char *tempdir;
-	char linkdir[128];
 	ssize_t i;
 
 	if (tflag != FTW_D || (strncmp((fpath + ftwbuf->base), searchbusid,
@@ -387,12 +396,12 @@ dinfo_is_busiddir(const char *fpath, const struct stat *UNUSED(sb),
 	 */
 	if (asprintf(&tempdir, "%s/driver", fpath) < 0)
 		return -1;
-	i = readlink(tempdir, linkdir, 128);
+	i = readlink(tempdir, linkdir, LINK_DIR_SIZE);
 	free(tempdir);
-	if ((i < 0) || (i >= 128))
+	if (i < 0 || i >= LINK_DIR_SIZE)
 		return -1;
 	/* append '\0' because readlink returns non zero terminated string */
-	tempdir[i + 1] = '\0';
+	linkdir[i] = '\0';
 	if (strstr(linkdir, "dasd") == NULL)
 		return FTW_CONTINUE;
 	free(busiddir);
@@ -439,7 +448,7 @@ dinfo_get_blockdev_from_busid(char *busid, char **blkdev)
 
 	char *tempdir = NULL;
 	char *result = NULL;
-	char *sysfsdir = "/sys/devices/";
+	char *sysfsdir = util_path_sysfs("devices/");
 
 	/* dinfo_is_devnode needs to know the busid */
 	searchbusid = busid;
@@ -475,6 +484,7 @@ out:
 out2:
 	free(busiddir);
 	free(result);
+	free(sysfsdir);
 	return rc;
 }
 
@@ -486,6 +496,7 @@ static int dinfo_get_uid_from_devnode(char **uidfile, char *devnode)
 	DIR *directory = NULL;
 	struct dirent *dir_entry = NULL;
 	int rc = 0;
+	char *path;
 
 	if (stat(devnode, &stat_buffer) != 0) {
 		warnx("Error: could not stat %s", devnode);
@@ -495,32 +506,34 @@ static int dinfo_get_uid_from_devnode(char **uidfile, char *devnode)
 	sprintf(stat_dev, "%d:%d", major(stat_buffer.st_rdev),
 		minor(stat_buffer.st_rdev));
 
-	directory = opendir("/sys/block/");
+	path = util_path_sysfs("block/");
+	directory = opendir(path);
 	if (directory == NULL) {
-		warnx("Error: could not open directory /sys/block");
+		warnx("Error: could not open directory %s", path);
+		free(path);
 		return -1;
 	}
 
 	readbuf = dinfo_malloc(RD_BUFFER_SIZE);
 	if (!readbuf) {
 		warnx("Error: Not enough memory to allocate readbuffer");
+		free(path);
 		return -1;
 	}
 
 	while ((dir_entry = readdir(directory)) != NULL) {
-		if (util_file_read_line(readbuf, RD_BUFFER_SIZE,
-					"/sys/block/%s/dev",
+		if (util_file_read_line(readbuf, RD_BUFFER_SIZE, "%s%s/dev", path,
 					dir_entry->d_name) < 0)
 			continue;
 
 		if (strncmp(stat_dev, readbuf,
 			    MAX(strlen(stat_dev), strlen(readbuf) - 1)) == 0) {
-			rc = snprintf(*uidfile, RD_BUFFER_SIZE,
-				      "/sys/block/%s/device/uid",
+			rc = snprintf(*uidfile, RD_BUFFER_SIZE, "%s%s/device/uid", path,
 				      dir_entry->d_name);
 			if (rc >= RD_BUFFER_SIZE) {
 				fprintf(stderr,
 					"Error: Device name was truncated\n");
+				free(path);
 				return -1;
 			}
 
@@ -529,6 +542,7 @@ static int dinfo_get_uid_from_devnode(char **uidfile, char *devnode)
 	}
 
 	closedir(directory);
+	free(path);
 	return 0;
 }
 
@@ -626,16 +640,18 @@ int main(int argc, char *argv[])
 	}
 
 	readbuf = dinfo_malloc(RD_BUFFER_SIZE);
-	uidfile = dinfo_malloc(RD_BUFFER_SIZE);
-	if (!(readbuf && uidfile))
+	if (!readbuf)
 		exit(1);
 
 	/* try to read the uid attribute */
 	if (busid) {
-		sprintf(uidfile, "/sys/bus/ccw/devices/%s/uid", busid);
+		uidfile = util_path_sysfs("bus/ccw/devices/%s/uid", busid);
 	} else if (blockdev) {
-		sprintf(uidfile, "/sys/block/%s/device/uid", blockdev);
+		uidfile = util_path_sysfs("block/%s/device/uid", blockdev);
 	} else if (devnode) {
+		uidfile = dinfo_malloc(RD_BUFFER_SIZE);
+		if (!uidfile)
+			exit(1);
 		if (dinfo_get_uid_from_devnode(&uidfile, devnode) != 0)
 			goto error;
 	}
