@@ -28,6 +28,8 @@ enum util_arch_machine_type {
 	UTIL_ARCH_MACHINE_TYPE_Z15_T02	= 8562,
 	UTIL_ARCH_MACHINE_TYPE_Z16	= 3931,
 	UTIL_ARCH_MACHINE_TYPE_Z16_A02	= 3932,
+	UTIL_ARCH_MACHINE_TYPE_Z17	= 9175,
+	UTIL_ARCH_MACHINE_TYPE_Z17_2	= 9176,
 };
 
 int util_arch_machine_type(void);
