@@ -9,7 +9,6 @@
  * it under the terms of the MIT license. See LICENSE for details.
  */
 
-#include <errno.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -49,19 +48,19 @@ static int device_sysfs_path(const char *device, char *path, const size_t path_s
  */
 int ccw_is_device(const char *busid)
 {
-	char path[PATH_MAX];
+	static const char *const driver_paths[] = { "dasd-eckd", "virtio_ccw", "dasd-fba" };
+	char *path;
+	size_t i;
+
+	for (i = 0; i < ARRAY_SIZE(driver_paths); i++) {
+		path = util_path_sysfs("bus/ccw/drivers/%s/%s", driver_paths[i], busid);
+		if (access(path, R_OK) == 0) {
+			free(path);
+			return 1;
+		}
+		free(path);
+	}
 
-	snprintf(path, sizeof(path),
-		 "/sys/bus/ccw/drivers/dasd-eckd/%s", busid);
-	if (access(path, R_OK) == 0)
-		return 1;
-	snprintf(path, sizeof(path),
-		 "/sys/bus/ccw/drivers/virtio_ccw/%s", busid);
-	if (access(path, R_OK) == 0)
-		return 1;
-	snprintf(path, sizeof(path), "/sys/bus/ccw/drivers/dasd-fba/%s", busid);
-	if (access(path, R_OK) == 0)
-		return 1;
 	return 0;
 }
 
@@ -72,6 +71,7 @@ int ccw_is_virtio_device(const char *device)
 {
 	char path[PATH_MAX] = { '\0' };
 	unsigned virtio = 0;
+	char *path_pattern;
 
 	if (device_sysfs_path(device, path, sizeof(path)) != 0)
 		return -1;
@@ -80,76 +80,37 @@ int ccw_is_virtio_device(const char *device)
 	 * The output has the following format:
 	 * /sys/devices/css0/0.0.0000/0.0.0000/virtio0/block/vda
 	 */
-	if (sscanf(path, "/sys/devices/css0/%*[0-9a-f.]/%*[0-9a-f.]/virtio%u", &virtio) != 1)
+	path_pattern = util_path_sysfs("devices/css0/%%*[0-9a-f.]/%%*[0-9a-f.]/virtio%%u");
+	if (sscanf(path, path_pattern, &virtio) != 1) {
+		free(path_pattern);
 		return -1;
+	}
+	free(path_pattern);
 	return 0;
 }
 
 /*
- * Return CCW Bus ID (old sysfs)
+ * Return CCW Bus ID
  */
-static int ccw_busid_get_sysfs_old(const char *device, char *busid)
-{
-	char path[PATH_MAX];
-	char buf[4096];
-	int rc = 0;
-	FILE *fh;
-
-	snprintf(path, sizeof(path), "/sys/block/%s/uevent", device);
-	fh = fopen(path, "r");
-	if (fh == NULL)
-		return -1;
-	/*
-	 * The uevent file contains an entry like this:
-	 * PHYSDEVPATH=/devices/css0/0.0.206a/0.0.7e78
-	 */
-	while (fscanf(fh, "%s", buf) >= 0) {
-		if (strstr(buf, "PHYSDEVPATH") != NULL) {
-			strcpy(busid, strrchr(buf, '/') + 1);
-			goto out_fclose;
-		}
-	}
-	rc = -1;
-out_fclose:
-	fclose(fh);
-	return rc;
-}
-
-/*
- * Return CCW Bus ID (new sysfs)
- */
-static int ccw_busid_get_sysfs_new(const char *device, char *busid)
+void ccw_busid_get(const char *device, char *busid)
 {
 	char path[PATH_MAX] = { '\0' };
+	char *path_pattern;
 
 	if (device_sysfs_path(device, path, sizeof(path)) != 0)
-		return -1;
+		ERR_EXIT("Could not lookup device number for \"%s\"", device);
 
 	/*
 	 * The output has the following format:
 	 * /sys/devices/css0/0.0.0119/0.0.3f19/block/dasda
 	 * /sys/devices/css0/0.0.0000/0.0.0000/virtio0/block/vda
 	 */
-	if (sscanf(path, "/sys/devices/css0/%*[0-9a-f.]/%[0-9a-f.]", busid) != 1)
-		return -1;
-	return 0;
-}
+	path_pattern = util_path_sysfs("devices/css0/%%*[0-9a-f.]/%%[0-9a-f.]");
+	if (sscanf(path, path_pattern, busid) != 1) {
+		free(path_pattern);
+		ERR_EXIT("Could not lookup device number for \"%s\"", device);
+	}
+	free(path_pattern);
 
-/*
- * Return the device number for a device
- * dasda can be found in /sys/block/dasda/uevent or in a
- * symbolic link in the same directory. the first file only
- * contains the relevant information if we run on a kernel with
- * has the following kernel option enabled:
- * CONFIG_SYSFS_DEPRECATED
- *
- * This does not work when booting from tape
- */
-void ccw_busid_get(const char *device, char *busid)
-{
-	if (ccw_busid_get_sysfs_old(device, busid) == 0)
-		return;
-	if (ccw_busid_get_sysfs_new(device, busid) == 0)
-		return;
-	ERR_EXIT("Could not lookup device number for \"%s\"", device);
+	return;
 }
