@@ -12,10 +12,12 @@ mod config;
 mod helper;
 mod uv;
 
-use ap::{Apqn, ApqnList};
+use ap::ApqnList;
 use cli::ARGS;
 use config::{ApConfigEntry, ApConfigList};
 use helper::{LockFile, PATH_PVAPCONFIG_LOCK};
+use pv_core::ap::{self as pvap, Apqn};
+use pv_core::misc::encode_hex;
 use pv_core::uv::{ListableSecretType, SecretList};
 use std::process::ExitCode;
 use utils::print_version;
@@ -84,42 +86,48 @@ fn main() -> ExitCode {
     on_error_print_and_exit!(r);
     info!("UV support and environment is ok.\n");
 
-    // read configuration
-    let configfile: &str = match &cli::ARGS.config {
-        Some(f) => f,
-        _ => cli::PATH_DEFAULT_CONFIG_FILE,
-    };
-    info!(
-        "Reading AP configuration entries from file '{}'...\n",
-        configfile
-    );
-    let apconfig: ApConfigList = match ApConfigList::read_and_validate_yaml_file(configfile) {
-        Ok(apcfg) => apcfg,
-        Err(err) => println_and_exit_failure!("{}", err),
-    };
-    if apconfig.is_empty() {
-        println!(
-            "No AP configuration entries in config file '{}': Nothing to do.",
+    let mut apconfig: ApConfigList = Default::default();
+    if !cli::ARGS.unbind {
+        // read configuration
+        let configfile: &str = match &cli::ARGS.config {
+            Some(f) => f,
+            _ => cli::PATH_DEFAULT_CONFIG_FILE,
+        };
+        info!(
+            "Reading AP configuration entries from file '{}'...\n",
             configfile
         );
-        return ExitCode::SUCCESS;
-    }
-    info!("Found {} AP configuration entries.\n", apconfig.len());
+        apconfig = match ApConfigList::read_and_validate_yaml_file(configfile) {
+            Ok(apcfg) => apcfg,
+            Err(err) => println_and_exit_failure!("{}", err),
+        };
+        if apconfig.is_empty() {
+            println!(
+                "No AP configuration entries in config file '{}': Nothing to do.",
+                configfile
+            );
+            return ExitCode::SUCCESS;
+        }
+        info!("Found {} AP configuration entries.\n", apconfig.len());
+    };
 
     // get list of secrets from UV
-    info!("Fetching list of secrets from UV...\n");
-    let secrets: SecretList = match uv::gather_secrets() {
-        Err(e) => println_and_exit_failure!("{}", e),
-        Ok(los) => los,
-    };
-    info!("Fetched {} Secret entries from UV.\n", secrets.len());
+    let mut secrets = SecretList::new(0, Vec::new());
+    if !cli::ARGS.unbind {
+        info!("Fetching list of secrets from UV...\n");
+        secrets = match uv::gather_secrets() {
+            Err(e) => println_and_exit_failure!("{}", e),
+            Ok(los) => los,
+        };
+        info!("Fetched {} Secret entries from UV.\n", secrets.len());
+    }
 
     // Warning if no UV secrets given but AP config entries require it
     let non_accel_apc = apconfig
         .iter()
         .filter(|apc| apc.mode != config::STR_MODE_ACCEL)
         .count();
-    if non_accel_apc > 0 && secrets.is_empty() {
+    if !cli::ARGS.unbind && non_accel_apc > 0 && secrets.is_empty() {
         println!(
             "Warning: No UV Secrets given but at least one AP config entry requires a Secret."
         );
@@ -151,7 +159,7 @@ fn main() -> ExitCode {
         Ok(n) => n,
     };
 
-    if n == 0 {
+    if !cli::ARGS.unbind && n == 0 {
         println_and_exit_failure!(
             "None out of {} AP config entries could be applied.",
             apconfig.len()
@@ -164,11 +172,13 @@ fn main() -> ExitCode {
         );
     }
 
-    info!(
-        "Successfully applied {} out of {} AP config entries.\n",
-        n,
-        apconfig.len()
-    );
+    if !cli::ARGS.unbind {
+        info!(
+            "Successfully applied {} out of {} AP config entries.\n",
+            n,
+            apconfig.len()
+        );
+    }
 
     ExitCode::SUCCESS
 }
@@ -224,14 +234,14 @@ fn do_ap_config(
                 continue;
             }
             match apqn.mode {
-                ap::ApqnMode::Accel => {
+                pvap::apqn_mode::Accel => {
                     // check bind state of this APQN
                     let bind_state_ok = match apqn.bind_state() {
                         Err(err) => {
                             eprintln!("Warning: Failure reading APQN {apqn} bind state: {err}");
                             false
                         }
-                        Ok(ap::BindState::Bound) => true,
+                        Ok(pvap::bind_state::Bound) => true,
                         Ok(_) => false,
                     };
                     if !bind_state_ok {
@@ -246,7 +256,7 @@ fn do_ap_config(
                     resolved_entries += 1;
                     break;
                 }
-                ap::ApqnMode::Ep11 => {
+                pvap::apqn_mode::Ep11 => {
                     // check association state of this APQN
                     let (assoc_state_ok, assoc_idx) = match apqn.associate_state() {
                         Err(err) => {
@@ -255,7 +265,7 @@ fn do_ap_config(
                             );
                             (false, 0)
                         }
-                        Ok(ap::AssocState::Associated(idx)) => (true, idx),
+                        Ok(pvap::assoc_state::Associated(idx)) => (true, idx),
                         Ok(_) => (false, 0),
                     };
                     if !assoc_state_ok {
@@ -266,7 +276,7 @@ fn do_ap_config(
                         se.stype() == ListableSecretType::Association
                             && se.id().len() == uv::AP_ASSOC_SECRET_ID_SIZE
                             && se.index() == assoc_idx
-                            && helper::u8_to_hexstring(se.id()) == apc.secretid
+                            && encode_hex(se.id()) == apc.secretid
                     });
                     if r.is_none() {
                         continue;
@@ -297,10 +307,10 @@ fn do_ap_config(
         }
         match apqn.bind_state() {
             Err(err) => eprintln!("Warning: Failure reading APQN {apqn} bind state: {err}"),
-            Ok(ap::BindState::Bound) => {
+            Ok(pvap::bind_state::Bound) => {
                 info!("Unbind APQN {apqn} as this bind/associate does not match to any AP config entry.\n");
                 if !ARGS.dryrun() {
-                    if let Err(err) = apqn.set_bind_state(ap::BindState::Unbound) {
+                    if let Err(err) = apqn.set_bind_state(pvap::bind_state::Unbound) {
                         return Err(format!("Failure unbinding APQN {apqn}: {err}"));
                     }
                 }
@@ -330,15 +340,15 @@ fn do_ap_config(
                 continue;
             }
             match apqn.mode {
-                ap::ApqnMode::Accel => {
+                pvap::apqn_mode::Accel => {
                     // try to bind this accelerator APQN
                     if ARGS.verbose() || fntest {
                         println!("Bind APQN {apqn} to match to AP config entry {cistr}.");
                     }
                     if !(ARGS.dryrun() || fntest) {
-                        if let Err(err) = apqn.set_bind_state(ap::BindState::Bound) {
+                        if let Err(err) = apqn.set_bind_state(pvap::bind_state::Bound) {
                             // bind failed, unbind/reset this apqn, return with failure
-                            let _ = apqn.set_bind_state(ap::BindState::Unbound);
+                            let _ = apqn.set_bind_state(pvap::bind_state::Unbound);
                             return Err(format!("Failure binding APQN {apqn}: {err}"));
                         }
                     }
@@ -347,13 +357,13 @@ fn do_ap_config(
                     resolved_entries += 1;
                     break;
                 }
-                ap::ApqnMode::Ep11 => {
+                pvap::apqn_mode::Ep11 => {
                     // EP11 needs bind and associate, but before doing this let's
                     // check out which secret index to use with the associate
                     let se = match secrets.iter().find(|&se| {
                         se.stype() == ListableSecretType::Association
                             && se.id().len() == uv::AP_ASSOC_SECRET_ID_SIZE
-                            && helper::u8_to_hexstring(se.id()) == apc.secretid
+                            && encode_hex(se.id()) == apc.secretid
                     }) {
                         None => {
                             eprintln!("Warning: Secret id '{}' from config entry {} not found in UV secrets list.",
@@ -369,9 +379,9 @@ fn do_ap_config(
                         );
                     }
                     if !(ARGS.dryrun() || fntest) {
-                        if let Err(err) = apqn.set_bind_state(ap::BindState::Bound) {
+                        if let Err(err) = apqn.set_bind_state(pvap::bind_state::Bound) {
                             // bind failed, unbind/reset this apqn, return with failure
-                            let _ = apqn.set_bind_state(ap::BindState::Unbound);
+                            let _ = apqn.set_bind_state(pvap::bind_state::Unbound);
                             return Err(format!("Failure binding APQN {}: {}", apqn, err));
                         }
                     }
@@ -383,7 +393,7 @@ fn do_ap_config(
 			);
                     }
                     if !(ARGS.dryrun() || fntest) {
-                        let apas = ap::AssocState::Associated(se.index());
+                        let apas = pvap::assoc_state::Associated(se.index());
                         apqn.set_associate_state(apas)
                             .map_err(|err| format!("Failure associating APQN {apqn}: {err}"))?;
                     }
@@ -408,7 +418,7 @@ fn do_ap_config(
 /// Please note this can not happen, as mingen is already checked via RE
 /// during storing the value into mingen.
 fn config_and_apqn_match(apc: &ApConfigEntry, apqn: &Apqn) -> bool {
-    if apc.mode == config::STR_MODE_ACCEL && apqn.mode == ap::ApqnMode::Accel {
+    if apc.mode == config::STR_MODE_ACCEL && apqn.mode == pvap::apqn_mode::Accel {
         // config and apqn are accelerators
         // maybe check mingen
         if !apc.mingen.is_empty() {
@@ -418,10 +428,10 @@ fn config_and_apqn_match(apc: &ApConfigEntry, apqn: &Apqn) -> bool {
             }
         }
         return true;
-    } else if apc.mode == config::STR_MODE_EP11 && apqn.mode == ap::ApqnMode::Ep11 {
+    } else if apc.mode == config::STR_MODE_EP11 && apqn.mode == pvap::apqn_mode::Ep11 {
         // config and apqn are ep11
         let info = match &apqn.info {
-            Some(ap::ApqnInfo::Ep11(i)) => i,
+            Some(pvap::apqn_info::Ep11(i)) => i,
             _ => return false,
         };
         // maybe check mingen
@@ -450,79 +460,78 @@ fn config_and_apqn_match(apc: &ApConfigEntry, apqn: &Apqn) -> bool {
 mod tests {
 
     use super::*;
-    use helper::hexstring_to_u8;
-    use pv_core::uv::SecretEntry;
+    use pv_core::{misc::decode_hex, uv::SecretEntry};
 
     // This is more or less only a test for the do_ap_config() function
     // However, this is THE main functionality of the whole application.
 
     fn make_test_apqns() -> Vec<Apqn> {
         vec![
-            ap::Apqn {
+            pvap::Apqn {
                 name: String::from("10.0007"),
                 card: 16,
                 domain: 7,
                 gen: 8,
-                mode: ap::ApqnMode::Accel,
-                info: Option::Some(ap::ApqnInfo::Accel(ap::ApqnInfoAccel {})),
+                mode: pvap::apqn_mode::Accel,
+                info: Option::Some(pvap::apqn_info::Accel(pvap::apqn_info::ApqnInfoAccel {})),
             },
-            ap::Apqn {
+            pvap::Apqn {
                 name: String::from("11.0008"),
                 card: 17,
                 domain: 8,
                 gen: 8,
-                mode: ap::ApqnMode::Ep11,
-                info: Option::Some(ap::ApqnInfo::Ep11(ap::ApqnInfoEp11 {
+                mode: pvap::apqn_mode::Ep11,
+                info: Option::Some(pvap::apqn_info::Ep11(pvap::apqn_info::ApqnInfoEp11 {
                     serialnr: String::from("93AADFK719460083"),
                     mkvp: String::from("db3c3b3c3f097dd55ec7eb0e7fdbcb93"),
                 })),
             },
-            ap::Apqn {
+            pvap::Apqn {
                 name: String::from("12.0009"),
                 card: 18,
                 domain: 9,
                 gen: 8,
-                mode: ap::ApqnMode::Ep11,
-                info: Option::Some(ap::ApqnInfo::Ep11(ap::ApqnInfoEp11 {
+                mode: pvap::apqn_mode::Ep11,
+                info: Option::Some(pvap::apqn_info::Ep11(pvap::apqn_info::ApqnInfoEp11 {
                     serialnr: String::from("93AADHZU42082261"),
                     mkvp: String::from("4a27bb66520ac85f6073a7f678d262c0"),
                 })),
             },
-            ap::Apqn {
+            pvap::Apqn {
                 name: String::from("12.000a"),
                 card: 18,
                 domain: 10,
                 gen: 8,
-                mode: ap::ApqnMode::Ep11,
-                info: Option::Some(ap::ApqnInfo::Ep11(ap::ApqnInfoEp11 {
+                mode: pvap::apqn_mode::Ep11,
+                info: Option::Some(pvap::apqn_info::Ep11(pvap::apqn_info::ApqnInfoEp11 {
                     serialnr: String::from("93AADHZU42082261"),
                     mkvp: String::from("383d2a9ab781f35343554c5b3d9337cd"),
                 })),
             },
-            ap::Apqn {
+            pvap::Apqn {
                 name: String::from("13.000d"),
                 card: 19,
                 domain: 13,
                 gen: 8,
-                mode: ap::ApqnMode::Ep11,
-                info: Option::Some(ap::ApqnInfo::Ep11(ap::ApqnInfoEp11 {
+                mode: pvap::apqn_mode::Ep11,
+                info: Option::Some(pvap::apqn_info::Ep11(pvap::apqn_info::ApqnInfoEp11 {
                     serialnr: String::from("87HU397G150TZGR"),
                     mkvp: String::new(),
                 })),
             },
-            ap::Apqn {
+            pvap::Apqn {
                 name: String::from("13.000f"),
                 card: 19,
                 domain: 15,
                 gen: 8,
-                mode: ap::ApqnMode::Ep11,
+                mode: pvap::apqn_mode::Ep11,
                 info: Option::None,
             },
         ]
     }
 
     fn make_assoc_secretentry(idx: u16, hexidstr: &str) -> SecretEntry {
-        let id = hexstring_to_u8(hexidstr);
+        let id = decode_hex(hexidstr).unwrap();
         let idlen: u32 = id.len().try_into().unwrap();
         let idarray: [u8; 32] = id.try_into().unwrap();
         SecretEntry::new(idx, ListableSecretType::Association, idarray.into(), idlen)
