@@ -2,13 +2,13 @@
 //
 // Copyright IBM Corp. 2024
 
-use std::path::{Path, PathBuf};
+use std::path::PathBuf;
 
 use anyhow::Result;
 use log::info;
 use pv::{misc::read_file, request::Confidential};
 
-use crate::cli::CreateBootImageExperimentalArgs;
+use crate::cli::UserKeys;
 
 #[macro_export]
 /// Makes it easier to
@@ -23,13 +23,9 @@ pub struct UserProvidedKeys {
 }
 
 /// Reads all user provided keys.
-pub fn read_user_provided_keys(
-    cck_path: Option<&Path>,
-    hdr_key_path: Option<&Path>,
-    experimental_args: &CreateBootImageExperimentalArgs,
-) -> Result<UserProvidedKeys> {
+pub fn read_user_provided_keys(keys: &UserKeys) -> Result<UserProvidedKeys> {
     let components_key = {
-        match &experimental_args.x_comp_key {
+        match &keys.image_key {
             Some(key_path) => {
                 info!(
                     "Use file '{}' as the image components protection key",
@@ -44,7 +40,7 @@ pub fn read_user_provided_keys(
         }
     };
     let aead_key = {
-        match hdr_key_path {
+        match &keys.hdr_key {
             Some(key_path) => {
                 info!(
                     "Use file '{}' as the Secure Execution header protection",
@@ -63,7 +59,7 @@ pub fn read_user_provided_keys(
     };
 
     let cck = {
-        match cck_path {
+        match &keys.cck {
             Some(key_path) => {
                 info!(
                     "Use file '{}' as the customer communication key (CCK)",
