@@ -1,26 +1,26 @@
-/*************************************************************************
+/*
+ * tape390_crypt: Provide encryption for tape devices
  *
- * File...........: s390-tools/tape390/tape390_crypt.c
- * Author(s)......: Frank Munzert <munzert@de.ibm.com>
- *                  Michael Holzheu <holzheu@de.ibm.com>
+ * Copyright 2006, 2017 IBM Corp.
  *
- * Copyright IBM Corp. 2006.
- *
- *************************************************************************/
+ * s390-tools is free software; you can redistribute it and/or modify
+ * it under the terms of the MIT license. See LICENSE for details.
+ */
 
-#include <unistd.h>
-#include <stdio.h>
-#include <sys/ioctl.h>
+#include <ctype.h>
 #include <errno.h>
 #include <getopt.h>
+#include <libgen.h>
 #include <limits.h>
+#include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <ctype.h>
-#include <libgen.h>
+#include <sys/ioctl.h>
 #include <sys/mtio.h>
-#include "zt_common.h"
-#include "tape390_common.h" 
+#include <unistd.h>
+
+#include "lib/zt_common.h"
+#include "tape390_common.h"
 
 #define KEKL_LENGTH 65 /* 64 bytes plus trailing \0 */
 #define TOT_KEKL_LENGTH KEKL_LENGTH+1+5 /* kekl plus colon plus LABEL or HASH */
@@ -130,7 +130,7 @@ struct tape390_kekl_pair {
 static const char tool_name[] = "tape390_crpyt: zSeries tape encryption program";
 
 /* Copyright notice */
-static const char copyright_notice[] = "Copyright IBM Corp. 2006";
+static const char copyright_notice[] = "Copyright IBM Corp. 2006, 2017";
 
 /*
  * Print version information.
@@ -193,7 +193,7 @@ static void tape390_crypt_parse_opts(struct tape390_crypt *info, int argc,
 		{ "help",        no_argument,       NULL, 'h'},
 		{ "delimiter",   required_argument, NULL, 'd'},
 		{ "force",       no_argument,       NULL, 'f'},
-		{ 0,             0,                 0,    0  }
+		{ NULL,          0,                 NULL,  0 }
 	};
 	/* Command line option abbreviations */
 	static const char crypt_option_string[] = "ve:qk:hd:f";
@@ -283,7 +283,7 @@ static void tape390_crypt_parse_opts(struct tape390_crypt *info, int argc,
 			    "%s: No device specified.\n",prog_name);
 	if (optind + 1 < argc)
 		ERRMSG_EXIT(EXIT_MISUSE,
-			    "%s: More than one device speficied.\n",prog_name);
+			    "%s: More than one device specified.\n",prog_name);
 	strcpy(info->devname, argv[optind]);
 }
 
@@ -369,13 +369,13 @@ static int tell_tape(int fd)
 
 /*
  * Do read IO to tape in order to enforce update of KEKL information.
- * Leave tape position inchanged.
+ * Leave tape position unchanged.
  */
 
 static int read_tape(int fd)
 {
 	struct mtop mtop;
-	int block_number, rc, n_read;
+	int block_number, n_read;
 	char buffer[MAX_BLOCKSIZE];
 
 	/* remember current block on tape */
@@ -392,7 +392,8 @@ static int read_tape(int fd)
 		/* re-position tape */
 		mtop.mt_op = MTSEEK;
 		mtop.mt_count = block_number;
-		rc = ioctl(fd, MTIOCTOP, &mtop);
+		if (ioctl(fd, MTIOCTOP, &mtop) != 0)
+			return 1;
 	}
 	return 0;
 }
