@@ -265,6 +265,7 @@ static struct {
 	unsigned long unit;
 	char unit_suffix;
 	bool unit_specified;
+	bool unit_iec;
 } opts;
 
 /* Per CHPID run-time data. */
@@ -336,6 +337,7 @@ static void init_opts(void)
 	opts.unit           = UNIT_AUTO;
 	opts.unit_suffix    = 0;
 	opts.unit_specified = false;
+	opts.unit_iec       = false;
 }
 
 /*
@@ -459,6 +461,37 @@ static void parse_cmgs(char *arg)
 	}
 }
 
+static bool suffix_to_unit(char *arg, unsigned long *unit_ptr, char *suffix_ptr,
+			   bool *iec_ptr)
+{
+	const char *suffixes = "KMGT";
+	unsigned long unit, base;
+	size_t len = strlen(arg);
+	char suffix;
+	bool iec;
+	int i;
+
+	if (len == 1)
+		iec = false;
+	else if (len == 2 && toupper(arg[1]) == 'I')
+		iec = true;
+	else
+		return false;
+	suffix = (char)toupper(*arg);
+	base = iec ? UNIT_BIN : UNIT_DEC;
+	unit = base;
+	for (i = 0; suffixes[i]; i++) {
+		if (suffix == suffixes[i]) {
+			*unit_ptr = unit;
+			*suffix_ptr = suffix;
+			*iec_ptr = iec;
+			return true;
+		}
+		unit *= base;
+	}
+	return false;
+}
+
 /*
  * Parse a scale unit value in @arg and return the resulting scaling factor.
  */
@@ -467,22 +500,12 @@ static unsigned long parse_unit(char *arg)
 	unsigned long unit;
 	char *endptr;
 
-	if (strlen(arg) == 1) {
-		opts.unit_suffix = (char)toupper(*arg);
-		switch (opts.unit_suffix) {
-		case 'K':
-			return UNIT_BIN;
-		case 'M':
-			return UNIT_BIN * UNIT_BIN;
-		case 'G':
-			return UNIT_BIN * UNIT_BIN * UNIT_BIN;
-		case 'T':
-			return UNIT_BIN * UNIT_BIN * UNIT_BIN * UNIT_BIN;
-		default:
-			break;
-		}
+	if (suffix_to_unit(arg, &unit, &opts.unit_suffix, &opts.unit_iec))
+		return unit;
+	if (strcmp(arg, "auto-iec") == 0) {
+		opts.unit_iec = true;
+		return UNIT_AUTO;
 	}
-	opts.unit_suffix = 0;
 	if (strcmp(arg, "auto") == 0)
 		return UNIT_AUTO;
 	/* Parse as number. */
@@ -1278,7 +1301,7 @@ static struct util_rec *define_table(void)
 	rec = util_rec_new_wide(NULL);
 	column_for_each_selected(col) {
 		util_rec_def(rec, col->name, UTIL_REC_ALIGN_RIGHT,
-			     (int)col->width, "");
+			     (int)col->width + (int)col->pad, "");
 	}
 
 	return rec;
@@ -1343,7 +1366,7 @@ static void scale_fixed(struct cmg_pair_t *p, unsigned long unit)
 static void add_pair_value(struct util_rec *table, struct column_t *col,
 			   struct cmg_pair_t *pair)
 {
-	char suffix = 0, str[16];
+	char suffix = 0, suffix2 = opts.unit_iec ? 'i' : 0, str[16];
 	int p;
 
 	if (!pair->valid) {
@@ -1355,23 +1378,25 @@ static void add_pair_value(struct util_rec *table, struct column_t *col,
 		suffix = scale_auto(pair, UNIT_DEC);
 	} else if (pair->unit == CMG_BPS) {
 		if (opts.unit == UNIT_AUTO)
-			suffix = scale_auto(pair, UNIT_BIN);
+			suffix = scale_auto(pair, opts.unit_iec ? UNIT_BIN : UNIT_DEC);
 		else
 			scale_fixed(pair, opts.unit);
 	}
 
 	switch (pair->type) {
 	case CMG_U32:
-		snprintf(str, sizeof(str), "%u%c", pair->value_u32, suffix);
+		snprintf(str, sizeof(str), "%u%c%c", pair->value_u32, suffix,
+			 suffix2);
 		break;
 	case CMG_U64:
-		snprintf(str, sizeof(str), "%llu%c", pair->value_u64, suffix);
+		snprintf(str, sizeof(str), "%llu%c%c", pair->value_u64, suffix,
+			 suffix2);
 		break;
 	case CMG_FLOAT:
 		/* Find highest precision that fits into @width characters. */
 		for (p = 2; p >= 0; p--) {
-			snprintf(str, sizeof(str), "%.*f%c", p,
-				 pair->value_double, suffix);
+			snprintf(str, sizeof(str), "%.*f%c%c", p,
+				 pair->value_double, suffix, suffix2);
 			if (strlen(str) <= col->width)
 				break;
 		}
@@ -1539,11 +1564,15 @@ static void print_table_header(void)
 {
 	struct column_t *col;
 	unsigned int i, next_i, num, width, hdr_width;
+	const char *last_hdr1 = NULL;
 
 	/* Print first header line and update column width based on heading. */
 	for (i = 0; (col = column_get_by_index(i, true)); i = next_i) {
-		if (i > 0)
-			printf(" ");
+		if (last_hdr1 && strcmp(last_hdr1, col->hdr1_group) != 0) {
+			col->pad = 1;
+			printf("%*s", col->pad + 1, "");
+		}
+		last_hdr1 = col->hdr1_group;
 		get_hdr_group_size(i, &num, &width);
 		if (num == 1) {
 			/* Update column width in case heading is wider. */
@@ -1571,7 +1600,7 @@ static void print_table_header(void)
 	i = 0;
 	column_for_each_selected(col) {
 		if (i++ > 0)
-			printf(" ");
+			printf("%*s", col->pad + 1, "");
 		printf("%*s", col->width, col->hdr2);
 	}
 	printf("\n");
@@ -1667,8 +1696,8 @@ static void calc_column_widths(void)
 				width = 4; /* "999K" */
 			} else {
 				v = MAX_BPS / (double)opts.unit;
-				snprintf(str, sizeof(str) - 1, "%.0f%c", v,
-					 opts.unit_suffix);
+				snprintf(str, sizeof(str) - 1, "%.0f%c%c", v,
+					 opts.unit_suffix, opts.unit_iec ? 'i' : 0);
 				width = strlen_u(str);
 			}
 			break;
@@ -1678,7 +1707,7 @@ static void calc_column_widths(void)
 		col->width = MAX(col->width, width);
 		/* Double space between groups. */
 		if (last_hdr1 && strcmp(last_hdr1, col->hdr1_group) != 0)
-			col->width++;
+			col->pad++;
 		last_hdr1 = col->hdr1_group;
 	}
 }
@@ -1693,7 +1722,8 @@ static void cmd_table(void)
 
 	apply_column_selection();
 	calc_column_widths();
-	column_update_bps_suffix(opts.unit == UNIT_AUTO, opts.unit_suffix);
+	column_update_bps_suffix(opts.unit == UNIT_AUTO, opts.unit_iec,
+				 opts.unit_suffix);
 
 	printf("Collecting initial utilization data\n");
 	update_util_all(true);
