@@ -53,6 +53,7 @@ static struct column_t columns[] = {
 		HDR1_CHP_SINGLE,
 		HDR1_CHP_GROUP,
 		0,
+		0,
 	},
 	{
 		COL_TYPE,
@@ -63,6 +64,7 @@ static struct column_t columns[] = {
 		HDR1_CHP_SINGLE,
 		HDR1_CHP_GROUP,
 		0,
+		0,
 	},
 	{
 		COL_CMG,
@@ -73,6 +75,7 @@ static struct column_t columns[] = {
 		HDR1_CHP_SINGLE,
 		HDR1_CHP_GROUP,
 		0,
+		0,
 	},
 	{
 		COL_SPEED,
@@ -83,6 +86,7 @@ static struct column_t columns[] = {
 		HDR1_CHP_SINGLE,
 		HDR1_CHP_GROUP,
 		0,
+		0,
 	},
 	{
 		COL_SHARED,
@@ -93,6 +97,7 @@ static struct column_t columns[] = {
 		HDR1_CHP_SINGLE,
 		HDR1_CHP_GROUP,
 		0,
+		0,
 	},
 	{
 		COL_INTERVAL,
@@ -103,6 +108,7 @@ static struct column_t columns[] = {
 		HDR1_CHP_SINGLE,
 		HDR1_CHP_GROUP,
 		0,
+		0,
 	},
 	{
 		COL_UTIL_PART,
@@ -112,6 +118,7 @@ static struct column_t columns[] = {
 		"PART",
 		HDR1_UTIL_SINGLE,
 		HDR1_UTIL_GROUP,
+		5,
 		0,
 	},
 	{
@@ -122,6 +129,7 @@ static struct column_t columns[] = {
 		"TOTAL",
 		HDR1_UTIL_SINGLE,
 		HDR1_UTIL_GROUP,
+		5,
 		0,
 	},
 	{
@@ -133,6 +141,7 @@ static struct column_t columns[] = {
 		HDR1_UTIL_SINGLE,
 		HDR1_UTIL_GROUP,
 		0,
+		0,
 	},
 	{
 		COL_UTIL_DATA,
@@ -143,6 +152,7 @@ static struct column_t columns[] = {
 		HDR1_UTIL_SINGLE,
 		HDR1_UTIL_GROUP,
 		0,
+		0,
 	},
 	{
 		COL_READ_PART,
@@ -152,6 +162,7 @@ static struct column_t columns[] = {
 		"PART",
 		HDR1_READ_SINGLE,
 		HDR1_READ_GROUP,
+		5,
 		0,
 	},
 	{
@@ -162,6 +173,7 @@ static struct column_t columns[] = {
 		"TOTAL",
 		HDR1_READ_SINGLE,
 		HDR1_READ_GROUP,
+		5,
 		0,
 	},
 	{
@@ -172,6 +184,7 @@ static struct column_t columns[] = {
 		"PART",
 		HDR1_WRITE_SINGLE,
 		HDR1_WRITE_GROUP,
+		5,
 		0,
 	},
 	{
@@ -182,6 +195,7 @@ static struct column_t columns[] = {
 		"TOTAL",
 		HDR1_WRITE_SINGLE,
 		HDR1_WRITE_GROUP,
+		5,
 		0,
 	},
 	{
@@ -193,6 +207,7 @@ static struct column_t columns[] = {
 		HDR1_FICON_SINGLE,
 		HDR1_FICON_GROUP,
 		0,
+		0,
 	},
 	{
 		COL_FICON_ACTIVE,
@@ -203,6 +218,7 @@ static struct column_t columns[] = {
 		HDR1_FICON_SINGLE,
 		HDR1_FICON_GROUP,
 		0,
+		0,
 	},
 	{
 		COL_FICON_DEFER,
@@ -213,6 +229,7 @@ static struct column_t columns[] = {
 		HDR1_FICON_SINGLE,
 		HDR1_FICON_GROUP,
 		0,
+		0,
 	},
 	{
 		COL_HPF_RATE,
@@ -223,6 +240,7 @@ static struct column_t columns[] = {
 		HDR1_HPF_SINGLE,
 		HDR1_HPF_GROUP,
 		0,
+		0,
 	},
 	{
 		COL_HPF_ACTIVE,
@@ -233,6 +251,7 @@ static struct column_t columns[] = {
 		HDR1_HPF_SINGLE,
 		HDR1_HPF_GROUP,
 		0,
+		0,
 	},
 	{
 		COL_HPF_DEFER,
@@ -243,6 +262,7 @@ static struct column_t columns[] = {
 		HDR1_HPF_SINGLE,
 		HDR1_HPF_GROUP,
 		0,
+		0,
 	},
 	{
 		COL_MSG_RATE_PART,
@@ -252,6 +272,7 @@ static struct column_t columns[] = {
 		"PART",
 		HDR1_MSGR_SINGLE,
 		HDR1_MSGR_GROUP,
+		5,
 		0,
 	},
 	{
@@ -262,6 +283,7 @@ static struct column_t columns[] = {
 		"TOTAL",
 		HDR1_MSGR_SINGLE,
 		HDR1_MSGR_GROUP,
+		5,
 		0,
 	},
 	{
@@ -272,6 +294,7 @@ static struct column_t columns[] = {
 		"PART",
 		HDR1_MSGSZ_SINGLE,
 		HDR1_MSGSZ_GROUP,
+		5,
 		0,
 	},
 	{
@@ -282,6 +305,7 @@ static struct column_t columns[] = {
 		"TOTAL",
 		HDR1_MSGSZ_SINGLE,
 		HDR1_MSGSZ_GROUP,
+		5,
 		0,
 	},
 	{
@@ -293,6 +317,7 @@ static struct column_t columns[] = {
 		"SNDFAIL",
 		"SNDFAIL",
 		0,
+		0,
 	},
 	{
 		COL_RCV_FAIL_PART,
@@ -302,6 +327,7 @@ static struct column_t columns[] = {
 		"PART",
 		HDR1_MSG_RCVF_SINGLE,
 		HDR1_MSG_RCVF_GROUP,
+		5,
 		0,
 	},
 	{
@@ -312,6 +338,7 @@ static struct column_t columns[] = {
 		"TOTAL",
 		HDR1_MSG_RCVF_SINGLE,
 		HDR1_MSG_RCVF_GROUP,
+		5,
 		0,
 	},
 	{
@@ -323,6 +350,7 @@ static struct column_t columns[] = {
 		HDR1_DPU_UTIL_SINGLE,
 		HDR1_DPU_UTIL_GROUP,
 		0,
+		0,
 	},
 	{
 		COL_DPU_UTIL,
@@ -333,6 +361,7 @@ static struct column_t columns[] = {
 		HDR1_DPU_UTIL_SINGLE,
 		HDR1_DPU_UTIL_GROUP,
 		0,
+		0,
 	},
 	{
 		COL_DPU_UTIL_PART,
@@ -342,6 +371,7 @@ static struct column_t columns[] = {
 		"PART",
 		HDR1_DPU_UTIL_SINGLE,
 		HDR1_DPU_UTIL_GROUP,
+		5,
 		0,
 	},
 	{
@@ -352,6 +382,7 @@ static struct column_t columns[] = {
 		"TOTAL",
 		HDR1_DPU_UTIL_SINGLE,
 		HDR1_DPU_UTIL_GROUP,
+		5,
 		0,
 	},
 };
@@ -447,15 +478,17 @@ void column_select_all(void)
 		column_select(col);
 }
 
-void column_update_bps_suffix(bool auto_scale, char suffix_char)
+void column_update_bps_suffix(bool auto_scale, bool iec, char suffix_char)
 {
 	struct column_t *col;
 	char *str;
 
 	if (auto_scale)
 		util_asprintf(&str, "(B/s)");
-	else if (suffix_char)
+	else if (suffix_char && iec)
 		util_asprintf(&str, "(%ciB/s)", suffix_char);
+	else if (suffix_char)
+		util_asprintf(&str, "(%cB/s)", suffix_char);
 	else
 		str = util_strdup("(*)");
 
