@@ -29,6 +29,7 @@ struct device *device_new(struct subtype *st, const char *id)
 {
 	struct device *dev;
 	struct namespace *ns = st->namespace;
+	int i;
 
 	dev = misc_malloc(sizeof(struct device));
 	dev->subtype = st;
@@ -44,12 +45,17 @@ struct device *device_new(struct subtype *st, const char *id)
 	dev->persistent.settings = setting_list_new();
 	dev->autoconf.settings = setting_list_new();
 
+	for (i = 0; i < NUM_SITES; i++)
+		dev->site_specific[i].settings = setting_list_new();
+
 	return dev;
 }
 
 /* Release all resources associated with the specified device. */
 void device_free(struct device *dev)
 {
+	int i;
+
 	if (!dev)
 		return;
 	free(dev->id);
@@ -57,12 +63,18 @@ void device_free(struct device *dev)
 	setting_list_free(dev->active.settings);
 	setting_list_free(dev->persistent.settings);
 	setting_list_free(dev->autoconf.settings);
+
+	for (i = 0; i  < NUM_SITES; i++)
+		setting_list_free(dev->site_specific[i].settings);
+
 	free(dev);
 }
 
 /* Used for debugging. */
 void device_print(struct device *dev, int level)
 {
+	int i;
+
 	printf("%*sdevice at %p:\n", level, "", (void *) dev);
 	if (!dev)
 		return;
@@ -96,6 +108,36 @@ void device_print(struct device *dev, int level)
 		setting_list_print(dev->autoconf.settings, level + 8);
 	else
 		printf("%*s<none>\n", level + 8, "");
+
+	printf("%*spersistent-site-specific:\n", level + 4, "");
+	for (i = 0; i < NUM_SITES; i++) {
+		printf("%*sexists=%d mod=%d deconf=%d\n",
+		       level + 8, "", dev->site_specific[i].exists,
+		       dev->site_specific[i].modified,
+		       dev->site_specific[i].deconfigured);
+		if (dev->site_specific[i].settings)
+			setting_list_print(dev->site_specific[i].settings, level + 8);
+		else
+			printf("%*s<none>\n", level + 8, "");
+	}
+}
+
+char *device_get_sites(struct device *dev)
+{
+	struct util_list *names;
+	char *str;
+	int i;
+
+	names = strlist_new();
+	for (i = 0; i < NUM_USER_SITES; i++) {
+		if (dev->site_specific[i].exists)
+			strlist_add(names, "%d", i);
+	}
+
+	str = strlist_flatten(names, ",");
+	strlist_free(names);
+
+	return str;
 }
 
 static const void *device_hash_get_id(void *dev_ptr)
@@ -627,10 +669,16 @@ exit_code_t device_check_settings(struct device *dev, config_t config,
 }
 
 struct setting_list *device_get_setting_list(struct device *dev,
-					     config_t config)
+					     config_t config,
+					     int site_id)
 {
 	struct setting_list *settings = NULL;
 
+	if (site_id < SITE_FALLBACK) {
+		settings = dev->site_specific[site_id].settings;
+		goto out;
+	}
+
 	if (config == config_active)
 		settings = dev->active.settings;
 	else if (config == config_persistent)
@@ -638,6 +686,7 @@ struct setting_list *device_get_setting_list(struct device *dev,
 	else if (config == config_autoconf)
 		settings = dev->autoconf.settings;
 
+out:
 	return settings;
 }
 
@@ -657,3 +706,21 @@ config_t device_get_config(struct device *dev)
 
 	return config;
 }
+
+/* Determine if persistent configuration available for any of the sites*/
+bool is_dev_pers(struct device *dev)
+{
+	int i;
+
+	if (global_site_id != SITE_FALLBACK &&
+	    !dev->site_specific[global_site_id].exists)
+		return false;
+	else if (dev->persistent.exists)
+		return true;
+
+	for (i = 0; i < NUM_SITES; i++)
+		if (dev->site_specific[i].exists)
+			return true;
+
+	return false;
+}
