@@ -89,6 +89,7 @@ enum {
 	OPT_ONLINE		= (OPT_ANONYMOUS_BASE+__COUNTER__),
 	OPT_OFFLINE		= (OPT_ANONYMOUS_BASE+__COUNTER__),
 	OPT_FAILED		= (OPT_ANONYMOUS_BASE+__COUNTER__),
+	OPT_IPLDEV		= (OPT_ANONYMOUS_BASE+__COUNTER__),
 	OPT_BY_PATH		= (OPT_ANONYMOUS_BASE+__COUNTER__),
 	OPT_BY_NODE		= (OPT_ANONYMOUS_BASE+__COUNTER__),
 	OPT_BY_INTERFACE	= (OPT_ANONYMOUS_BASE+__COUNTER__),
@@ -129,6 +130,7 @@ static struct opts_conflict conflict_list[] = {
 	OPTS_CONFLICT(OPT_TYPE,
 		      OPT_CONFIGURED, OPT_EXISTING, OPT_ONLINE, OPT_OFFLINE,
 		      OPT_BY_PATH, OPT_BY_NODE, OPT_BY_INTERFACE, OPT_FAILED,
+		      OPT_IPLDEV,
 		      0),
 	OPTS_CONFLICT(OPT_SITE,
 		      OPT_TYPE),
@@ -148,6 +150,7 @@ static const struct option opt_list[] = {
 	{ "online",		no_argument,	NULL, OPT_ONLINE },
 	{ "offline",		no_argument,	NULL, OPT_OFFLINE },
 	{ "failed",		no_argument,	NULL, OPT_FAILED },
+	{ "ipldev",		no_argument,	NULL, OPT_IPLDEV },
 	{ "by-path",		required_argument, NULL, OPT_BY_PATH },
 	{ "by-node",		required_argument, NULL, OPT_BY_NODE },
 	{ "by-interface",	required_argument, NULL, OPT_BY_INTERFACE },
@@ -609,6 +612,11 @@ static exit_code_t parse_options(struct options *opts, int argc, char *argv[])
 			opts->select->failed = 1;
 			break;
 
+		case OPT_IPLDEV:
+			/* --ipldev */
+			opts->select->ipldev = 1;
+			break;
+
 		case OPT_BY_PATH:
 			/* --by-path MOUNTPOINT */
 			strlist_add(&opts->select->by_path, "%s", optarg);
