@@ -19,22 +19,6 @@
 #include "dt.h"
 #include "zg.h"
 
-/*
- * Convert DFI arch to s390 arch
- */
-static inline enum df_s390_arch df_s390_from_dfi_arch(enum dfi_arch dfi_arch)
-{
-	return dfi_arch == DFI_ARCH_64 ? DF_S390_ARCH_64 : DF_S390_ARCH_32;
-}
-
-/*
- * Convert s390 arch to DFI arch
- */
-static inline enum dfi_arch df_s390_to_dfi_arch(enum df_s390_arch df_s390_arch)
-{
-	return df_s390_arch == DF_S390_ARCH_64 ? DFI_ARCH_64 : DFI_ARCH_32;
-}
-
 /*
  * Dump tool structure
  */
@@ -53,18 +37,15 @@ extern void df_s390_hdr_add(struct df_s390_hdr *hdr);
 extern void df_s390_em_add(struct df_s390_em *em);
 extern int df_s390_cpu_info_add(struct df_s390_hdr *hdr, u64 addr_max);
 extern int df_s390_em_verify(struct df_s390_em *em, struct df_s390_hdr *hdr);
-extern void df_s390_dumper_read(struct zg_fh *fh, int32_t blk_size,
-				struct df_s390_dumper *dumper);
+extern int df_s390_dumper_read(struct zg_fh *fh, int32_t blk_size,
+			       struct df_s390_dumper *dumper);
 
 /*
  * DASD dt and dfi functions
  */
-extern int dt_s390sv_init_gen(bool extended);
-extern int dt_s390mv_init_gen(bool extended);
+extern int dt_s390mv_ext_init(void);
 extern void dt_s390mv_info(void);
 
 extern int dfi_s390_init_gen(bool extended);
-extern int dfi_s390mv_init_gen(bool extended);
-extern void dfi_s390mv_info(void);
 
 #endif /* DF_S390_H */
