@@ -25,29 +25,6 @@
 enum dfi_arch {
 	DFI_ARCH_32		= 0,
 	DFI_ARCH_64		= 1,
-	DFI_ARCH_UNKNOWN	= 2,
-};
-
-struct dfi_lowcore_32 {
-	u8	pad_0x0000[0x0084 - 0x0000];	/* 0x0000 */
-	u16	cpu_addr;			/* 0x0084 */
-	u8	pad_0x0086[0x00d4 - 0x0086];	/* 0x0086 */
-	u32	extended_save_area_addr;	/* 0x00d4 */
-	u32	timer_save_area[2];		/* 0x00d8 */
-	u32	clock_comp_save_area[2];	/* 0x00e0 */
-	u32	mcck_interruption_code[2];	/* 0x00e8 */
-	u8	pad_0x00f0[0x00f4-0x00f0];	/* 0x00f0 */
-	u32	external_damage_code;		/* 0x00f4 */
-	u32	failing_storage_address;	/* 0x00f8 */
-	u8	pad_0x00fc[0x0100-0x00fc];	/* 0x00fc */
-	u32	st_status_fixed_logout[2];	/* 0x0100 */
-	u32	prefixreg_save_area;		/* 0x0108 */
-	u8	pad_0x0110[0x0120-0x010c];	/* 0x010c */
-	u32	access_regs_save_area[16];	/* 0x0120 */
-	u32	floating_pt_save_area[8];	/* 0x0160 */
-	u32	gpregs_save_area[16];		/* 0x0180 */
-	u32	cregs_save_area[16];		/* 0x01c0 */
-	u8	pad_0x0200[0x1000 - 0x0200];	/* 0x0200 */
 };
 
 struct dfi_lowcore_64 {
@@ -72,14 +49,6 @@ struct dfi_lowcore_64 {
 	u8	pad_0x1400[0x2000-0x1400];	/* 0x1400 */
 } __packed;
 
-static inline u64 dfi_lc_size(enum dfi_arch arch)
-{
-	if (arch == DFI_ARCH_64)
-		return 0x2000;
-	else
-		return 0x1000;
-}
-
 struct dfi_vxrs {
 	u64 low;
 	u64 high;
@@ -111,23 +80,6 @@ struct dfi_cpu {
 	u16		cpu_id;
 };
 
-struct dfi_cpu_32 {
-	u32		gprs[16];
-	u32		ctrs[16];
-	u32		acrs[16];
-	u64		fprs[4];
-	u32		psw[2];
-	u32		prefix;
-	u64		timer;
-	u64		todcmp;
-	u64		vxrs_low[16];
-	struct dfi_vxrs	vxrs_high[16];
-};
-
-void dfi_cpu_64_to_32(struct dfi_cpu_32 *cpu_32, struct dfi_cpu *cpu_64);
-
-enum dfi_arch dfi_arch(void);
-void dfi_arch_set(enum dfi_arch arch);
 const char *dfi_arch_str(enum dfi_arch arch);
 
 enum dfi_cpu_content {
@@ -192,9 +144,6 @@ unsigned int *dfi_attr_vol_nr(void);
 void dfi_attr_version_set(unsigned int dfi_version);
 unsigned int *dfi_attr_dfi_version(void);
 
-void dfi_attr_build_arch_set(enum dfi_arch build_arch);
-enum dfi_arch *dfi_attr_build_arch(void);
-
 void dfi_attr_real_cpu_cnt_set(u32 real_cpu_cnt);
 u32 *dfi_attr_real_cpu_cnt(void);
 
@@ -248,7 +197,6 @@ extern u64 dfi_live_dump_magic;
  * Supported DFI dump formats
  */
 extern struct dfi dfi_s390tape;
-extern struct dfi dfi_s390mv;
 extern struct dfi dfi_s390mv_ext;
 extern struct dfi dfi_s390;
 extern struct dfi dfi_s390_ext;
