@@ -88,7 +88,7 @@ void __noreturn zg_exit(int rc)
 /*
  * Alloc memory and check for errors
  */
-void *zg_alloc(unsigned int size)
+void *zg_alloc(size_t size)
 {
 	void *ptr = calloc(size, 1);
 	if (!ptr)
@@ -99,7 +99,7 @@ void *zg_alloc(unsigned int size)
 /*
  * Realloc memory and check for errors
  */
-void *zg_realloc(void *ptr, unsigned int size)
+void *zg_realloc(void *ptr, size_t size)
 {
 	void *new_ptr = realloc(ptr, size);
 	if (!new_ptr)
@@ -130,7 +130,7 @@ void zg_free(void *ptr)
 /*
  * Return path name of open file
  */
-const char *zg_path(struct zg_fh *zg_fh)
+const char *zg_path(const struct zg_fh *zg_fh)
 {
 	return zg_fh->path;
 }
@@ -138,7 +138,7 @@ const char *zg_path(struct zg_fh *zg_fh)
 /*
  * Return stat buffer of open file
  */
-const struct stat *zg_stat(struct zg_fh *zg_fh)
+const struct stat *zg_stat(const struct zg_fh *zg_fh)
 {
 	return &zg_fh->sb;
 }
@@ -183,13 +183,14 @@ fail:
 void zg_close(struct zg_fh *zg_fh)
 {
 	close(zg_fh->fh);
+	free((void *)zg_fh->path);
 	free(zg_fh);
 }
 
 /*
  * Read file
  */
-ssize_t zg_read(struct zg_fh *zg_fh, void *buf, size_t cnt, enum zg_check check)
+ssize_t zg_read(const struct zg_fh *zg_fh, void *buf, size_t cnt, enum zg_check check)
 {
 	size_t copied = 0;
 	ssize_t rc;
@@ -215,7 +216,7 @@ ssize_t zg_read(struct zg_fh *zg_fh, void *buf, size_t cnt, enum zg_check check)
 /*
  * Read line
  */
-ssize_t zg_gets(struct zg_fh *zg_fh, void *ptr, size_t cnt, enum zg_check check)
+ssize_t zg_gets(const struct zg_fh *zg_fh, void *ptr, size_t cnt, enum zg_check check)
 {
 	size_t copied = 0;
 	char *buf = ptr;
@@ -241,7 +242,7 @@ ssize_t zg_gets(struct zg_fh *zg_fh, void *ptr, size_t cnt, enum zg_check check)
 /*
  * Return file size
  */
-u64 zg_size(struct zg_fh *zg_fh)
+u64 zg_size(const struct zg_fh *zg_fh)
 {
 	return zg_fh->sb.st_size;
 }
@@ -249,7 +250,7 @@ u64 zg_size(struct zg_fh *zg_fh)
 /*
  * Return file position
  */
-off_t zg_tell(struct zg_fh *zg_fh, enum zg_check check)
+off_t zg_tell(const struct zg_fh *zg_fh, enum zg_check check)
 {
 	off_t rc;
 
@@ -263,7 +264,7 @@ off_t zg_tell(struct zg_fh *zg_fh, enum zg_check check)
 /*
  * Seek to "off" relative to END
  */
-off_t zg_seek_end(struct zg_fh *zg_fh, off_t off, enum zg_check check)
+off_t zg_seek_end(const struct zg_fh *zg_fh, off_t off, enum zg_check check)
 {
 	off_t rc;
 
@@ -276,7 +277,7 @@ off_t zg_seek_end(struct zg_fh *zg_fh, off_t off, enum zg_check check)
 /*
  * Seek to "off" in file
  */
-off_t zg_seek(struct zg_fh *zg_fh, off_t off, enum zg_check check)
+off_t zg_seek(const struct zg_fh *zg_fh, off_t off, enum zg_check check)
 {
 	off_t rc;
 
@@ -294,7 +295,7 @@ off_t zg_seek(struct zg_fh *zg_fh, off_t off, enum zg_check check)
 /*
  * Seek from current position
  */
-off_t zg_seek_cur(struct zg_fh *zg_fh, off_t off, enum zg_check check)
+off_t zg_seek_cur(const struct zg_fh *zg_fh, off_t off, enum zg_check check)
 {
 	off_t rc;
 
@@ -307,7 +308,7 @@ off_t zg_seek_cur(struct zg_fh *zg_fh, off_t off, enum zg_check check)
 /*
  * Do ioctl and exit in case of an error
  */
-int zg_ioctl(struct zg_fh *zg_fh, int rq, void *data, const char *op,
+int zg_ioctl(const struct zg_fh *zg_fh, unsigned long rq, void *data, const char *op,
 	     enum zg_check check)
 {
 	int rc;
@@ -322,10 +323,10 @@ int zg_ioctl(struct zg_fh *zg_fh, int rq, void *data, const char *op,
 /*
  * Return file type
  */
-enum zg_type zg_type(struct zg_fh *zg_fh)
+enum zg_type zg_type(const struct zg_fh *zg_fh)
 {
 	struct mtop mtop;
-	struct stat *sb = &zg_fh->sb;
+	const struct stat *sb = &zg_fh->sb;
 
 	if (S_ISREG(sb->st_mode))
 		return ZG_TYPE_FILE;
