@@ -3,19 +3,18 @@
  *
  * Stand-alone kdump support (stage 2)
  *
- * Copyright IBM Corp. 2013, 2017
+ * Copyright IBM Corp. 2013, 2023
  *
  * s390-tools is free software; you can redistribute it and/or modify
  * it under the terms of the MIT license. See LICENSE for details.
  */
 
-#include "error.h"
 #include "kdump.h"
 #include "libc.h"
 #include "menu.h"
 #include "stage2.h"
-
-static struct os_info **lc_os_info = ((struct os_info **)&S390_lowcore.os_info);
+#include "boot/error.h"
+#include "boot/os_info.h"
 
 /*
  * Copy crashkernel memory from [0, crash size] to
@@ -27,13 +26,13 @@ static struct os_info **lc_os_info = ((struct os_info **)&S390_lowcore.os_info);
  */
 void kdump_stage2(unsigned long config_nr)
 {
-	struct os_info *os_info = *lc_os_info;
+	const struct os_info *os_info = (struct os_info *)S390_lowcore.os_info;
 	unsigned long crash_size;
 	void *crash_base;
 
 	if (!(__stage2_params.config_kdump & (0x1 << config_nr)))
 		return;
-	os_info_check(os_info);
+	kdump_os_info_check(os_info);
 
 	/* Copy crashkernel memory */
 	crash_base = (void *) os_info->crashkernel_addr;
@@ -45,5 +44,5 @@ void kdump_stage2(unsigned long config_nr)
 	 */
 	if (__pa(os_info) >= crash_size)
 		return;
-	*lc_os_info = (void *) __pa(os_info) + __pa(crash_base);
+	S390_lowcore.os_info = __pa(os_info) + __pa(crash_base);
 }
