@@ -59,7 +59,7 @@ static int menu_read(void)
 		if (is_zvm())
 			for (i = 0; i < count; i++)
 				temp_area[i] = ebcdic_tolower(temp_area[i]);
-		value = ebcdic_strtoul((char *)temp_area, &endptr, 10);
+		value = ebcdic_strtoul(temp_area, &endptr, 10);
 
 		if ((endptr != temp_area) && (value < BOOT_MENU_ENTRIES - 1) &&
 		    (__stage2_params.config[value] != 0)) {
@@ -68,6 +68,7 @@ static int menu_read(void)
 		} else {
 			/* no valid config retry */
 			printf(msg_econfig);
+			memset(temp_area, 0, PAGE_SIZE);
 			count = 0;
 		}
 	}
@@ -97,6 +98,13 @@ static int menu_list(void)
 	return 0;
 }
 
+enum param_result {
+	NUMBER_FOUND  = 0,
+	PRINT_PROMPT  = 1,
+	NOTHING_FOUND = 2,
+	SCLP_ERROR    = 3,
+};
+
 /*
  * Interpret loadparm
  *
@@ -107,15 +115,20 @@ static int menu_list(void)
  *     0 - found number to boot, stored in value
  *     1 - print prompt
  *     2 - nothing found
+ *     3 - sclp error
  */
-static int menu_param(unsigned long *value)
+static enum param_result menu_param(unsigned long *value)
 {
 	char loadparm[PARAM_SIZE];
 	char *endptr;
 	int i;
 
-	if (!sclp_param(loadparm))
-		*value = ebcdic_strtoul(loadparm, &endptr, 10);
+	/* try to fetch loadparms from sclp into 'loadparm' */
+	if (sclp_param(loadparm) != 0)
+		return SCLP_ERROR;
+
+	/* parse number from loadparm */
+	*value = ebcdic_strtoul(loadparm, &endptr, 10);
 
 	/* got number, done */
 	if (endptr != loadparm)
@@ -127,39 +140,44 @@ static int menu_param(unsigned long *value)
 	while ((i < PARAM_SIZE) && ecbdic_isspace(loadparm[i]))
 		i++;
 
-	if (!strncmp(&loadparm[i], "PROMPT", 6)) {
-		*value = 0;
+	if (!strncmp(&loadparm[i], "PROMPT", 6))
 		return PRINT_PROMPT;
-	}
 
 	return NOTHING_FOUND;
 }
 
 int menu(void)
 {
-	unsigned long value = 0;
+	enum { DEFAULT_MENU_ENTRY = 0 };
+	unsigned long value = DEFAULT_MENU_ENTRY;
 	char *cmd_line_extra;
 	char endstring[15];
-	int rc;
 
 	cmd_line_extra = (char *)COMMAND_LINE_EXTRA;
 	memset(cmd_line_extra, 0, COMMAND_LINE_EXTRA_SIZE);
 
-	rc = sclp_setup(SCLP_INIT);
-	if (rc)
+	if (sclp_setup(SCLP_INIT) != 0) {
 		/* sclp setup failed boot default */
 		goto boot;
+	}
 
-	rc = menu_param(&value);
-	if (rc == 0) {
+	switch (menu_param(&value)) {
+	case NUMBER_FOUND:
 		/* got number from loadparm, boot it */
 		goto boot;
-	} else if (rc == 1 && value == 0) {
-		/* keyword "prompt", show menu */
-	} else if (__stage2_params.flag == 0) {
-		/* menu disabled, boot default */
-		value = 0;
+	case PRINT_PROMPT:
+		/* print menu */
+		break;
+	case SCLP_ERROR:
+		/* failed to read from sclp, boot default */
+		printf("SCLP_ERROR\n");
 		goto boot;
+	case NOTHING_FOUND:
+		if (__stage2_params.flag == 0) {
+			/* menu disabled, boot default */
+			goto boot;
+		}
+		break;
 	}
 
 	/* print banner */
