@@ -2,10 +2,11 @@
  * s390-tools/zipl/include/error.h
  *   Functions to handle error messages.
  *
- * Copyright (C) 2001-2003 IBM Deutschland Entwicklung GmbH, IBM Corporation
+ * Copyright IBM Corp. 2001, 2017
+ *
+ * s390-tools is free software; you can redistribute it and/or modify
+ * it under the terms of the MIT license. See LICENSE for details.
  *
- * Author(s): Carsten Otte <cotte@de.ibm.com>
- *            Peter Oberparleiter <Peter.Oberparleiter@de.ibm.com>
  */
 
 #ifndef ERROR_H
@@ -19,5 +20,6 @@ void error_text(const char* fmt, ...);
 void error_clear_reason(void);
 void error_clear_text(void);
 void error_print(void);
+int is_error(const char *this);
 
 #endif /* not ERROR_H */
