@@ -16,7 +16,7 @@
 #include "error.h"
 #include "misc.h"
 
-int bootmap_header_init(int fd)
+int bootmap_header_init(struct misc_fd *mfd)
 {
 	struct bootmap_header bh = {
 		.header_text =
@@ -25,40 +25,40 @@ int bootmap_header_init(int fd)
 		.version = BOOTMAP_HEADER_VERSION
 	};
 
-	return misc_write(fd, &bh, sizeof(bh));
+	return misc_write_or_simulate(mfd, &bh, sizeof(bh));
 }
 
-static int bootmap_header_access(int fd, struct bootmap_header *bh, int read)
+static int bootmap_header_access(struct misc_fd *mfd, struct bootmap_header *bh, int read)
 {
 	off_t cur_off;
 	int ret;
 
-	cur_off = lseek(fd, 0, SEEK_CUR);
+	cur_off = lseek(mfd->fd, 0, SEEK_CUR);
 	if (cur_off == -1) {
 		error_reason(strerror(errno));
 		return -1;
 	}
-	if (lseek(fd, 0, SEEK_SET) == -1) {
+	if (lseek(mfd->fd, 0, SEEK_SET) == -1) {
 		error_reason(strerror(errno));
 		ret = -1;
 		goto out;
 	}
 	if (read)
-		ret = misc_read(fd, bh, sizeof(*bh));
+		ret = misc_read(mfd->fd, bh, sizeof(*bh));
 	else
-		ret = misc_write(fd, bh, sizeof(*bh));
+		ret = misc_write_or_simulate(mfd, bh, sizeof(*bh));
 out:
-	if (lseek(fd, cur_off, SEEK_SET) == -1)
+	if (lseek(mfd->fd, cur_off, SEEK_SET) == -1)
 		return -1;
 	return ret;
 }
 
-int bootmap_header_read(int fd, struct bootmap_header *bh)
+int bootmap_header_read(struct misc_fd *mfd, struct bootmap_header *bh)
 {
-	return bootmap_header_access(fd, bh, 1);
+	return bootmap_header_access(mfd, bh, 1);
 }
 
-int bootmap_header_write(int fd, struct bootmap_header *bh)
+int bootmap_header_write(struct misc_fd *mfd, struct bootmap_header *bh)
 {
-	return bootmap_header_access(fd, bh, 0);
+	return bootmap_header_access(mfd, bh, 0);
 }
