@@ -131,6 +131,16 @@ int misc_open_device(const char *filename, struct misc_fd *mfd, int simulate)
 	return mfd->fd;
 }
 
+int misc_fsync(struct misc_fd *mfd, const char *filename)
+{
+	if (fsync(mfd->fd)) {
+		error_reason(strerror(errno));
+		error_text("Could not sync file '%s'", filename);
+		return -1;
+	}
+	return 0;
+}
+
 /* Read COUNT bytes of data from file identified by file descriptor FD to
  * memory at location BUFFER. Return 0 when all bytes were successfully read,
  * non-zero otherwise. */
@@ -434,7 +444,7 @@ misc_write(int fd, const void* data, size_t count)
 }
 
 /**
- * Instead of writing, upadte only current position in the file
+ * Instead of writing, update only current position in the file
  */
 static int misc_simulate_write(int fd, size_t count)
 {
