@@ -174,7 +174,8 @@ main(int argc, char* argv[])
 	/* Do it */
 	switch (job->id) {
 	case job_dump_partition:
-		rc = disk_get_ext_type(job->data.dump.device, &ext_type);
+		rc = disk_get_ext_type(job->data.dump.device, &ext_type,
+				       0 /* disk index */);
 		if (rc)
 			break;
 		job_dump_check_set_ngdump(job, &ext_type);
@@ -210,16 +211,16 @@ main(int argc, char* argv[])
 	case job_menu:
 		rc = prepare_bootloader(job, &bis);
 		if (rc) {
-			free_bootloader(&bis);
+			free_bootloader(&bis, job);
 			break;
 		}
 		rc = install_bootloader(job, &bis);
 		if (rc) {
-			free_bootloader(&bis);
+			free_bootloader(&bis, job);
 			break;
 		}
 		rc = post_install_bootloader(job, &bis);
-		free_bootloader(&bis);
+		free_bootloader(&bis, job);
 		break;
 	case job_ipl_tape:
 		rc = install_tapeloader(job->data.ipl_tape.device,
@@ -244,10 +245,6 @@ main(int argc, char* argv[])
 	}
 	switch (rc) {
 	case 0: /* Operation completed successfully */
-		if (verbose)
-			printf("Syncing disks...\n");
-		if (!dry_run)
-			sync();
 		printf("Done.\n");
 		break;
 	case -2: /* Operation canceled by user */
@@ -306,7 +303,8 @@ struct component_footer component_footers[NR_PROGRAM_COMPONENTS] = {
 	},
 	[COMPONENT_ID_ENVBLK] = {
 		.type = COMPONENT_TYPE_LOAD,
-		.desc = "environment blk"
+		.desc = "environment blk",
+		.fs_block_aligned = 1
 	},
 	[COMPONENT_ID_SEGMENT_FILE] = {
 		.type  = COMPONENT_TYPE_EXECUTE,
